Plugin: JS9Separate

### Separate and Gather Images

The Separate and Gather Images plugin allows you to separate selected images or all images into independent JS9 displays. The topmost (selected) image remains in place, and new displays are created for the others. The presence or absence of a menubar, toolbar, and colorbar in the topmost image will be replicated in the new displays.

You also can gather selected images or all images into the current display.

When separating images, the plugin allows you to choose between three layouts:

- horizontal: one row starting to the right of the first display
- vertical: one column underneath the first display
- auto: layout horizontally so long as half of each subsequent display is visible, then start a new row

The options to separate all and gather all images can also be found in the File menu (using the auto layout).